@@ -132,7 +132,7 @@ void SettingsBase::initToolBar()
     // Exit is the very last action
     quitAction = actionCollection()->addAction( KStandardAction::Quit, "quit_action", this, SLOT(close()) );
     // Configure goes at the end
-    configureAction = actionCollection()->addAction( KStandardAction::Preferences, this, SLOT(configShow()) );
+    configureAction = actionCollection()->addAction( KStandardAction::Preferences, "configure", this, SLOT(configShow()) );
     actionCollection()->setDefaultShortcut(configureAction, QKeySequence(Qt::CTRL + Qt::Key_M));
     configureAction->setText( i18n("Configure") );
     // Help after it
@@ -248,6 +248,7 @@ void SettingsBase::configUpdated()
     KWindowConfig::saveWindowSize(configDialog->windowHandle(), dialogConfig);
     BaseConfig::setActiveView( possibleViews.keys().at(viewSelection.checkedId()) );
     BaseConfig::setShowToolTips( configWidget.ChTooltips->isChecked() );
+    activeView->setShowToolTips( configWidget.ChTooltips->isChecked() );
     activeView->saveConfiguration();
     changePlugin();
 }
@@ -340,6 +341,7 @@ void SettingsBase::changePlugin()
             tooltipManagers << new ToolTipManager( view );
         }
     }
+    activeView->setShowToolTips( BaseConfig::showToolTips() );
 
     changeAboutMenu( activeView->aboutData(), aboutViewAction, i18n("About Active View") );
     viewChange(false);
@@ -391,6 +393,8 @@ void SettingsBase::changeToolBar( BaseMode::ToolBarItems toolbar )
         quitBarActions << quitAction;
         guiFactory()->plugActionList( this, "quit", quitBarActions );
     }
+
+    toolBar()->setVisible(toolbar != BaseMode::NoItems || (activeView && activeView->actionsList().count() > 0));
 }
 
 void SettingsBase::changeAboutMenu( const KAboutData * menuAbout, QAction * menuItem, QString fallback )
